/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.exceptions;

import org.neo4j.gqlstatus.ErrorGqlStatusObject;
import org.neo4j.kernel.api.exceptions.Status;

public class TransactionRetryAbortedException extends Neo4jException {
    public TransactionRetryAbortedException(String message, Throwable cause) {
        super(message, cause);
    }

    public TransactionRetryAbortedException(ErrorGqlStatusObject gqlStatusObject, String message, Throwable cause) {
        super(gqlStatusObject, message, cause);
    }

    public TransactionRetryAbortedException(String message) {
        super(message);
    }

    public TransactionRetryAbortedException(ErrorGqlStatusObject gqlStatusObject, String message) {
        super(gqlStatusObject, message);
    }

    @Override
    public Status status() {
        return Status.Statement.ExecutionTimeout;
    }

    public static TransactionRetryAbortedException transactionRetryAborted(
            Throwable cause, int retriedCount, String reason) {
        // TODO: Add GQL status object
        return new TransactionRetryAbortedException(
                String.format(
                        "Transaction retry aborted after %d attempts. %s. Last failed with cause: %s",
                        retriedCount, reason, cause.getMessage()),
                cause);
    }
}
