/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.gqlstatus;

import static org.neo4j.gqlstatus.GqlExceptionLikeAssert.catchGqlException;

import org.assertj.core.api.Assertions;
import org.assertj.core.api.ThrowableAssert;
import org.assertj.core.util.CanIgnoreReturnValue;

public class ErrorGqlStatusObjectAssertions {
    private ErrorGqlStatusObjectAssertions() {}

    public static ErrorGqlStatusObjectAssertImplementation assertThat(ErrorGqlStatusObject actual) {
        return new ErrorGqlStatusObjectAssertImplementation(actual);
    }

    public static <T extends Exception & ErrorGqlStatusObject> GqlExceptionLikeAssert assertThat(T actual) {
        return new GqlExceptionLikeAssert(actual);
    }

    @CanIgnoreReturnValue
    public static GqlExceptionLikeAssert assertThatThrownBy(ThrowableAssert.ThrowingCallable shouldRaiseThrowable) {
        return new GqlExceptionLikeAssert(catchGqlException(shouldRaiseThrowable));
    }

    @CanIgnoreReturnValue
    public static ThrowableWithPotentialGqlCauseAssert<?> assertThatNonGqlThrownBy(
            ThrowableAssert.ThrowingCallable shouldRaiseThrowable) {
        return new ThrowableWithPotentialGqlCauseAssert<>(Assertions.catchThrowable(shouldRaiseThrowable));
    }
}
